package com.ruoyi.ems.service.impl;

import java.util.List;

import com.ruoyi.ems.domain.vo.QueryIndex;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ems.mapper.ElecLoadIndexMapper;
import com.ruoyi.ems.domain.ElecLoadIndex;
import com.ruoyi.ems.service.IElecLoadIndexService;

/**
 * 电力负荷设施指标Service业务层处理
 *
 * @author ruoyi
 * @date 2024-08-09
 */
@Service
public class ElecLoadIndexServiceImpl implements IElecLoadIndexService {
    @Autowired
    private ElecLoadIndexMapper indexMapper;

    /**
     * 查询电力负荷设施指标
     *
     * @param id 电力负荷设施指标主键
     * @return 电力负荷设施指标
     */
    @Override
    public ElecLoadIndex selectIndexById(Long id) {
        return indexMapper.selectIndexById(id);
    }

    @Override
    public ElecLoadIndex selectNewIndex(String areaCode, String objType, String objCode) {
        return indexMapper.selectNewIndex(areaCode, objType, objCode);
    }

    @Override
    public List<ElecLoadIndex> selectByTime(QueryIndex queryIndex) {
        return indexMapper.selectByTime(queryIndex);
    }

    /**
     * 查询电力负荷设施指标列表
     *
     * @param admEmsElecLoadIndex 电力负荷设施指标
     * @return 电力负荷设施指标
     */
    @Override
    public List<ElecLoadIndex> selectIndexList(ElecLoadIndex admEmsElecLoadIndex) {
        return indexMapper.selectIndexList(admEmsElecLoadIndex);
    }

    /**
     * 新增电力负荷设施指标
     *
     * @param admEmsElecLoadIndex 电力负荷设施指标
     * @return 结果
     */
    @Override
    public int insertIndex(ElecLoadIndex admEmsElecLoadIndex) {
        return indexMapper.insertIndex(admEmsElecLoadIndex);
    }

    /**
     * 修改电力负荷设施指标
     *
     * @param admEmsElecLoadIndex 电力负荷设施指标
     * @return 结果
     */
    @Override
    public int updateIndex(ElecLoadIndex admEmsElecLoadIndex) {
        return indexMapper.updateIndex(admEmsElecLoadIndex);
    }

    /**
     * 批量删除电力负荷设施指标
     *
     * @param ids 需要删除的电力负荷设施指标主键
     * @return 结果
     */
    @Override
    public int deleteIndexByIds(Long[] ids) {
        return indexMapper.deleteIndexByIds(ids);
    }

    /**
     * 删除电力负荷设施指标信息
     *
     * @param id 电力负荷设施指标主键
     * @return 结果
     */
    @Override
    public int deleteIndexById(Long id) {
        return indexMapper.deleteIndexById(id);
    }
}
